==> db4o-5.0-mono.tar.gz: db4o-5.0/src/test/src/com/db4o/test/PersistStaticFieldValues.cs <==
/* Copyright (C) 2004 - 2005  db4objects Inc.  http://www.db4o.com

This file is part of the db4o open source object database.

db4o is free software; you can redistribute it and/or modify it under
the terms of version 2 of the GNU General Public License as published
by the Free Software Foundation and as clarified by db4objects' GPL 
interpretation policy, available at
http://www.db4o.com/about/company/legalpolicies/gplinterpretation/
Alternatively you can write to db4objects, Inc., 1900 S Norfolk Street,
Suite 350, San Mateo, CA 94403, USA.

db4o is distributed in the hope that it will be useful, but WITHOUT ANY
WARRANTY; without even the implied warranty of MERCHANTABILITY or
FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
for more details.

You should have received a copy of the GNU General Public License along
with this program; if not, write to the Free Software Foundation, Inc.,
59 Temple Place - Suite 330, Boston, MA  02111-1307, USA. */
using System;
using j4o.lang;
using com.db4o;
namespace com.db4o.test {

   public class PersistStaticFieldValues {
      
      public PersistStaticFieldValues() : base() {
      }
      static internal PsfvHelper ONE = new PsfvHelper();
      static internal PsfvHelper TWO = new PsfvHelper();
      static internal PsfvHelper THREE = new PsfvHelper();
      public PsfvHelper one;
      public PsfvHelper two;
      public PsfvHelper three;
      
      public void configure() {
         Db4o.configure().objectClass(this).persistStaticFieldValues();
      }
      
      public void store() {
         Tester.deleteAllInstances(this);
         PersistStaticFieldValues psfv1 = new PersistStaticFieldValues();
         psfv1.one = ONE;
         psfv1.two = TWO;
         psfv1.three = THREE;
         Tester.store(psfv1);
      }
      
      public void test() {
         PersistStaticFieldValues psfv1 = (PersistStaticFieldValues)Tester.getOne(this);
         Tester.ensure(psfv1.one == ONE);
         Tester.ensure(psfv1.two == TWO);
         Tester.ensure(psfv1.three == THREE);
      }
      
      public class PsfvHelper {
         
         public PsfvHelper() : base() {
         }
      }
   }
}

==> db4o-5.5-mono.tar.gz: db4o-5.5/src/test/src/com/db4o/test/PersistStaticFieldValues.cs <==
/* Copyright (C) 2004 - 2006  db4objects Inc.  http://www.db4o.com

This file is part of the db4o open source object database.

db4o is free software; you can redistribute it and/or modify it under
the terms of version 2 of the GNU General Public License as published
by the Free Software Foundation and as clarified by db4objects' GPL 
interpretation policy, available at
http://www.db4o.com/about/company/legalpolicies/gplinterpretation/
Alternatively you can write to db4objects, Inc., 1900 S Norfolk Street,
Suite 350, San Mateo, CA 94403, USA.

db4o is distributed in the hope that it will be useful, but WITHOUT ANY
WARRANTY; without even the implied warranty of MERCHANTABILITY or
FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
for more details.

You should have received a copy of the GNU General Public License along
with this program; if not, write to the Free Software Foundation, Inc.,
59 Temple Place - Suite 330, Boston, MA  02111-1307, USA. */
using System;
using j4o.lang;
using com.db4o;
namespace com.db4o.test {

   public class PersistStaticFieldValues {
      
      public PersistStaticFieldValues() : base() {
      }
      static internal PsfvHelper ONE = new PsfvHelper();
      static internal PsfvHelper TWO = new PsfvHelper();
      static internal PsfvHelper THREE = new PsfvHelper();
      public PsfvHelper one;
      public PsfvHelper two;
      public PsfvHelper three;
      
      public void Configure() {
         Db4o.Configure().ObjectClass(this).PersistStaticFieldValues();
      }
      
      public void Store() {
         Tester.DeleteAllInstances(this);
         PersistStaticFieldValues psfv1 = new PersistStaticFieldValues();
         psfv1.one = ONE;
         psfv1.two = TWO;
         psfv1.three = THREE;
         Tester.Store(psfv1);
      }
      
      public void Test() {
         PersistStaticFieldValues psfv1 = (PersistStaticFieldValues)Tester.GetOne(this);
         Tester.Ensure(psfv1.one == ONE);
         Tester.Ensure(psfv1.two == TWO);
         Tester.Ensure(psfv1.three == THREE);
      }
      
      public class PsfvHelper {
         
         public PsfvHelper() : base() {
         }
      }
   }
}
